@@ -1401,7 +1401,7 @@ class water:
             return rgb
 
 
-class imagedataset(objearth,Water):
+class imagedataset(objearth,water):
     def __init__(self,image_dataset):
         self.ids = image_dataset
     def detail(self):
